@@ -109,6 +109,7 @@ char *fake = N_("Get the determinantal divisors of an integer matrix (not its ch
 char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
 char *fake = N_("Get the eigenvalues of a matrix (Currently only for up to 4x4 or triangular matrices)");
+char *fake = N_("Get the eigenvalues and eigenvectors of a matrix (Currently only for up to 2x2 matrices)");
 char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use hermitian product)");
 char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
@@ -179,6 +180,8 @@ char *fake = N_("Calculate the nth triangular number");
 char *fake = N_("Calculate permutations");
 char *fake = N_("Integration of f by Composite Simpson's Rule on the interval [a,b] with the number of steps calculated by the fourth derivative bound and the desired tolerance");
 char *fake = N_("Attempt to calculate derivative by trying first symbolically and then numerically");
+char *fake = N_("Return a function which is the even periodic extension of f defined on the interval [0,L]");
+char *fake = N_("Return a function which is a Fourier series with the coefficients given by the vectors a (sines) and b (cosines).  Note that a@(1) is the constant coefficient!");
 char *fake = N_("Try to calculate an infinite product for a single parameter function");
 char *fake = N_("Try to calculate an infinite product for a double parameter function with func(arg,n)");
 char *fake = N_("Try to calculate an infinite sum for a single parameter function");
@@ -189,12 +192,20 @@ char *fake = N_("Calculate the left limit of a real-valued function at x0");
 char *fake = N_("Calculate the limit of a real-valued function at x0.  Tries to calculate both left and right limits.");
 char *fake = N_("Integration by midpoint rule");
 char *fake = N_("Attempt to calculate numerical derivative");
+char *fake = N_("Numerically compute the coefficients for a cosine Fourier series for a function on [0,L] up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier cosine series of f on [0,L] with coefficients up to N computed numerically");
+char *fake = N_("Numerically compute the coefficients for a Fourier series with half-period L up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier series of f with half-period L with coefficients up to N computed numerically");
+char *fake = N_("Numerically compute the coefficients for a sine Fourier series for a function on [0,L] up to the Nth coefficient.");
+char *fake = N_("Return a function which is the Fourier sine series of f on [0,L] with coefficients up to N computed numerically");
 char *fake = N_("Integration by rule set in NumericalIntegralFunction of f from a to b using NumericalIntegralSteps steps");
 char *fake = N_("Attempt to calculate numerical left derivative");
 char *fake = N_("Attempt to calculate the limit of f(step_fun(i)) as i goes from 1 to N");
 char *fake = N_("Attempt to calculate numerical right derivative");
+char *fake = N_("Return a function which is the odd periodic extension of f defined on the interval [0,L]");
 char *fake = N_("Compute one-sided derivative using five point formula");
 char *fake = N_("Compute one-sided derivative using three-point formula");
+char *fake = N_("Return a function which is the periodic extension of f defined on the interval [a,b]");
 char *fake = N_("Calculate the right limit of a real-valued function at x0");
 char *fake = N_("Compute two-sided derivative using five-point formula");
 char *fake = N_("Compute two-sided derivative using three-point formula");
